----------------
Permission model 
----------------

Rucio assigns permissions to accounts. Permissions are boolean flags designating 
whether an account may perform a certain action (read, write, delete) on a resource (RSE, account, replica, etc.). 
